package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class PolicyInformation extends ASN1Encodable {
   private DERObjectIdentifier policyIdentifier;
   private ASN1Sequence policyQualifiers;

   public PolicyInformation(ASN1Sequence seq) {
      if (seq.size() >= 1 && seq.size() <= 2) {
         this.policyIdentifier = DERObjectIdentifier.getInstance(seq.getObjectAt(0));
         if (seq.size() > 1) {
            this.policyQualifiers = ASN1Sequence.getInstance(seq.getObjectAt(1));
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public PolicyInformation(DERObjectIdentifier policyIdentifier) {
      this.policyIdentifier = policyIdentifier;
   }

   public PolicyInformation(DERObjectIdentifier policyIdentifier, ASN1Sequence policyQualifiers) {
      this.policyIdentifier = policyIdentifier;
      this.policyQualifiers = policyQualifiers;
   }

   public static PolicyInformation getInstance(Object obj) {
      return obj != null && !(obj instanceof PolicyInformation) ? new PolicyInformation(ASN1Sequence.getInstance(obj)) : (PolicyInformation)obj;
   }

   public DERObjectIdentifier getPolicyIdentifier() {
      return this.policyIdentifier;
   }

   public ASN1Sequence getPolicyQualifiers() {
      return this.policyQualifiers;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.policyIdentifier);
      ASN1Sequence var2;
      if ((var2 = this.policyQualifiers) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
